@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2019 Free Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -91,10 +91,11 @@ mu_readlink (const char *name, char **pbuf, size_t *psize, size_t *plen)
 	}
       size = 0;
     }
+  else if (plen)
+    *plen = linklen;
+  
   *pbuf = buf;
   *psize = size;
-  if (plen)
-    *plen = linklen;
   return status;
 }
 
