@@ -41,7 +41,8 @@ mail_decode (int argc, char **argv)
   msgset_t *msgset;
   struct decode_closure decode_closure;
 
-  if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT, &msgset))
+  if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT|MSG_ALLOWPART,
+		    &msgset))
     return 1;
 
   decode_closure.select_hdr = mu_islower (argv[0][0]);
