@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2005, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999-2022 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,9 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA */
+   along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "mail.h"
 
@@ -30,13 +28,9 @@ touch0 (msgset_t *mspec, mu_message_t msg, void *data)
   mu_attribute_t attr = NULL;
   
   mu_message_get_attribute (msg, &attr);
-  if (!mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_SAVED))
-    {
-      mu_attribute_set_userflag (attr, MAIL_ATTRIBUTE_MBOXED);
-      util_mark_read (msg);
-    }
+  mu_attribute_set_userflag (attr, MAIL_ATTRIBUTE_TOUCHED);
   
-  set_cursor (mspec->msg_part[0]);
+  set_cursor (msgset_msgno (mspec));
   return 0;
 }
 
